#include <QLabel>
#include <QListWidget>
#include <QComboBox>

#include "mainwindowimpl.h"
//
MainWindowImpl::MainWindowImpl( QWidget * parent, Qt::WFlags f) 
	: QMainWindow(parent, f)
{
	setupUi(this);
}

int print_callback(FANN::neural_net &net, FANN::training_data &train,
		unsigned int max_epochs, unsigned int epochs_between_reports,
		float desired_error, unsigned int epochs, void *user_data)
{
	win->lwLog->addItem(QString("Epochs %1, current error = %2")
			.arg(epochs)
			.arg(net.get_MSE()));
	return 0;
}


void MainWindowImpl::on_pbXORTest_clicked()
{
	const float learning_rate = 0.7f;
	const unsigned int num_layers = 3;
	const unsigned int num_input = 2;
	const unsigned int num_hidden = 3;
	const unsigned int num_output = 1;
	const float desired_error = 0.001f;
	const unsigned int max_iterations = 300000;
	const unsigned int iterations_between_reports = 1000;
	
	FANN::neural_net net;
	if (cbNetworkType->currentIndex() == 0)
		net.create_standard(num_layers, num_input, num_hidden, num_output);
	else
		net.create_shortcut(num_layers, num_input, num_hidden, num_output);
	
	net.set_learning_rate(learning_rate);
	
	net.set_activation_steepness_hidden(1.0);
	net.set_activation_steepness_output(1.0);
	
	net.set_activation_function_hidden(FANN::SIGMOID_SYMMETRIC_STEPWISE);
	net.set_activation_function_output(FANN::SIGMOID_SYMMETRIC_STEPWISE);
	
	// Set additional properties such as the training algorithm
	net.set_training_algorithm(FANN::TRAIN_QUICKPROP);
	
	net.print_parameters();

	lwLog->clear();
	lwLog->addItem("Training network...");

	FANN::training_data data;
	if (data.read_train_from_file("xor.data"))
	{
		// Initialize and train the network with the data
		net.init_weights(data);
		
		lwLog->addItem(QString("Max Epochs %1. Desired Error: %2").arg(max_iterations).arg(desired_error));
		net.set_callback(print_callback, NULL);
		net.train_on_data(data, max_iterations,
			iterations_between_reports, desired_error);
		
		lwLog->addItem("Testing network...");
		
		for (unsigned int i = 0; i < data.length_train_data(); ++i)
		{
			// Run the network on the test data
			fann_type *calc_out = net.run(data.get_input()[i]);
			
			lwLog->addItem(QString("XOR test (%1, %2) -> %3, shoud be %4, difference = %5")
					.arg(data.get_input()[i][0])
					.arg(data.get_input()[i][1])
					.arg(*calc_out)
					.arg(data.get_output()[i][0])
					.arg(fann_abs(*calc_out - data.get_output()[i][0])));
		}
		
		// Save the network in floating point and fixed point
		net.save("xor_float.net");
		unsigned int decimal_point = net.save_to_fixed("xor_fixed.net");
		data.save_train_to_fixed("xor_fixed.data", decimal_point);
		
		lwLog->addItem("XOR test completed.");
	}
}
