Module XorSample

    Sub Main()
        Try
            Console.Write(vbCrLf)
            Console.Write("Visual Basic XOR Sample - only works if fannKernel has been started..." & vbCrLf)

            Console.Write("Connect to fannKernel" & vbCrLf)
            Dim fann As fannProxy.fannKernel = New fannProxy.fannKernel
            Console.Write("Create a neural network context" & vbCrLf)
            Dim net As Integer = fann.CreateContext()

            Console.Write("Create the neural network and set its parameters" & vbCrLf)
            Dim layers() As Integer = {2, 3, 1}
            fann.Create(net, fannProxy.NetworkType.Layer, layers, 1.0F)
            fann.SetLearningRate(net, 0.7F)
            fann.SetActivationSteepnessHidden(net, 1.0)
            fann.SetActivationSteepnessOutput(net, 1.0)
            fann.SetActivationFunctionHidden(net, fannProxy.ActivationFunction.SigmoidSymmetricStepwise)
            fann.SetActivationFunctionOutput(net, fannProxy.ActivationFunction.SigmoidSymmetricStepwise)
            'fann.PrintParameters(net) 'Displays the network parameters in fannKernel

            Console.Write("Read training data from the xor.train sample file" & vbCrLf)
            fann.ReadTrainFromFile(net, "xor.train")

            Console.Write("Initialize and train the neural network" & vbCrLf)
            fann.InitWeights(net)
            Dim mse As Double()() = fann.TrainOnData(net, Convert.ToUInt32(300), Convert.ToUInt32(30), 0.001F)

            Console.Write("Output the mean square error information" & vbCrLf)
            Console.Write(vbTab & "Epoch" & vbTab & vbTab & "MSE" & vbCrLf)
            For i As Integer = 0 To mse.Length - 1
                Console.Write(vbTab)
                Console.Write(mse(i)(0))
                Console.Write(vbTab & vbTab)
                Console.Write(mse(i)(1))
                Console.Write(vbCrLf)
            Next i

            Console.Write("Execute the neural network on test data" & vbCrLf)
            Dim test0 As Double() = {-1, -1}
            Dim test1 As Double() = {-1, 1}
            Dim test2 As Double() = {1, -1}
            Dim test3 As Double() = {1, 1}
            Dim data As Double()() = {test0, test1, test2, test3}
            Dim result As Double()() = fann.RunData(net, data)

            Console.Write("Output the test data and results" & vbCrLf)
            Console.Write(vbTab & "Data" & vbTab & vbTab & "Result" & vbCrLf)
            For i As Integer = 0 To result(0).Length - 1
                Console.Write(vbTab)
                Console.Write("{0,2} xor {1,2}", data(i)(0), data(i)(1))
                Console.Write(vbTab)
                Console.Write(result(0)(i))
                Console.Write(vbCrLf)
            Next

            Console.Write("Remove the neural network from fannKernel" & vbCrLf)
            fann.DestroyContext(net)
        Catch fault As Exception
            Console.Write("Visual Basic XOR Sample Error: " & fault.Message & vbCrLf)
        End Try
    End Sub

End Module
