// Copyright 2005/2548 written by freegoldbar at yahoo dot com.
// All rights reserved. For private and educational use.
// Not for sale, commercial or military use.
// No warranties given. No suitability for any purpose.

//gsoap ns service name: fannKernel
//gsoap ns service style: rpc
//gsoap ns service encoding: encoded
//gsoap ns service namespace: http://127.0.0.1:2718/?wsdl
//gsoap ns service location: http://127.0.0.1:2718/
//gsoap ns service documentation: Fast Artificial Neural Network SOAP WSDL fannKernel interface
//gsoap ns schema namespace: urn:fann

// primitive types
typedef double xsd__double;
typedef float xsd__float;
typedef int xsd__int;
typedef unsigned int xsd__unsignedInt;
typedef std::string xsd__string;

// void result
typedef struct nothing { void *_; } ns__void_result;

// SOAP fann enumerations
enum ns__ErrorFunction { LinearError_ = 0, TanhError_};
enum ns__StopFunction { StopMSE_ = 0, StopBit_};
enum ns__TrainingAlgorithm { BackpropIncremental_ = 0,
    BackpropBatch_, Rprop_, Quickprop_};
enum ns__ActivationFunction { Linear_ = 0, Threshold_, ThresholdSymmetric_,
    Sigmoid_, SigmoidStepwise_, SigmoidSymmetric_, SigmoidSymmetricStepwise_,
    Gaussian_, GaussianSymmetric_, GaussianStepwise_,
    Elliot_, ElliotSymmetric_, LinearPiece_, LinearPieceSymmetric_,
    SinSymmetric_, CosSymmetric_};
enum ns__NetworkType {Layer_ = 0, Shortcut_};

//gsoap ns schema type-documentation: dvector dynamic array of type SOAP-ENC:Array with arrayType="double[]"
class dvector
{
public:
    xsd__double *__ptr; // pointer to array of double
    int __size; // number of elements pointed to
    struct soap *soap; // gSOAP env. instance was created
    dvector();
    dvector(struct soap *env);
    dvector(struct soap *env, int size);
    virtual ~dvector();
    virtual int size(); // dvector size
    virtual void set_size(int size);
    virtual double& operator[](int i);
};

//gsoap ns schema type-documentation: ivector dynamic array of type SOAP-ENC:Array with arrayType="int[]"
class ivector
{
public:
    xsd__int *__ptr; // pointer to array of int
    int __size; // number of elements pointed to
    struct soap *soap; // gSOAP env. instance was created
    ivector();
    ivector(struct soap *env);
    ivector(struct soap *env, int size);
    virtual ~ivector();
    virtual int size();  // ivector size
    virtual void set_size(int size);
    virtual int& operator[](int i);
};

//gsoap ns schema type-documentation: afvector dynamic array of type SOAP-ENC:Array with arrayType="enum ns__ActivationFunction[]"
class afvector
{
public:
    enum ns__ActivationFunction *__ptr; // pointer to array of enum ns__ActivationFunction
    int __size; // number of elements pointed to
    struct soap *soap; // gSOAP env. instance was created
    afvector();
    afvector(struct soap *env);
    afvector(struct soap *env, int size);
    virtual ~afvector();
    virtual int size();  // afvector size
    virtual void set_size(int size);
    virtual enum ns__ActivationFunction& operator[](int i);
};

//gsoap ns schema type-documentation: dmatrix dynamic array of type SOAP-ENC:Array with arrayType="double[][]"
class dmatrix
{
public:
    dvector *__ptr; // pointer to array of dvectors
    int __size; // number of dvectors pointed to
    struct soap *soap; // gSOAP env. instance was created
    dmatrix();
    dmatrix(struct soap *env);
    dmatrix(struct soap *env, int rows, int cols);
    virtual ~dmatrix();
    virtual int size();
    virtual void set_size(int rows, int cols);
    virtual dvector& operator[](int i);
};

//gsoap ns schema type-documentation: stringvector dynamic array of type SOAP-ENC:Array with arrayType="string[]"
class stringvector
{
public:
    xsd__string *__ptr[]; // pointer to array of string
    int __size; // number of elements pointed to
    struct soap *soap; // gSOAP env. instance was created
    stringvector();
    stringvector(struct soap *env);
    stringvector(struct soap *env, int size);
    virtual ~stringvector();
    virtual int size(); // stringvector size
    virtual void resize(int size);
    virtual std::string& operator[](int i);
};

// SOAP fann function declarations

//gsoap ns service method-documentation: CreateContext creates a kernel context with a default neural network, empty training/test data and returns its id
int ns__CreateContext(void *noarg, int *context);
//gsoap ns service method-documentation: DestroyContext removes a neural network and data context from the kernel
int ns__DestroyContext(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: GetContextList returns a list of id's of currently active neural network contexts
int ns__GetContextList(void *noarg, ivector *contexts);
//gsoap ns service method-documentation: PrintContexts lists active context information on the kernel console
int ns__PrintContexts(void *noarg, ns__void_result *noresult);
//gsoap ns service method-documentation: KeepAlive updates the timestamp of a context so it does not expire even if it is unused
int ns__KeepAlive(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: GetFileList returns a list of files from the net subdirectory with the given filetype extension (.net, .train or .test)
int ns__GetFileList(std::string filetype, stringvector *filelist);

//gsoap ns service method-documentation: GetNetName returns the name of the neural network that it was loaded from or saved to.
int ns__GetNetName(int context, std::string &filename);
//gsoap ns service method-documentation: GetTrainName  returns the name of the training data that it was loaded from or saved to.
int ns__GetTrainName(int context, std::string &filename);
//gsoap ns service method-documentation: GetTestName  returns the name of the test data that it was loaded from or saved to.
int ns__GetTestName(int context, std::string &filename);

//gsoap ns service method-documentation: Create creates a neural network of Layer or Shortcut type - a Layer net can be created with fewer connections by setting the connection rate to less than one
int ns__Create(int context, enum ns__NetworkType nettype, ivector *layers, float connectionrate, bool *success);
//gsoap ns service method-documentation: CreateFromFile loads a neural network from the named configuration file
int ns__CreateFromFile(int context, std::string configurationfile, bool *success);
//gsoap ns service method-documentation: RunNet executes a neural network with the input data and returns its output
int ns__RunNet(int context, dvector *input, dvector *output);
//gsoap ns service method-documentation: RunData executes a neural network with each of the input data and returns its corresponding output
int ns__RunData(int context, dmatrix *input, dmatrix *output);
//gsoap ns service method-documentation: RunTrainData executes a neural network with the training data and returns its corresponding output
int ns__RunTrainData(int context, dmatrix *output);
//gsoap ns service method-documentation: RunTestData executes a neural network with the test data and returns its corresponding output
int ns__RunTestData(int context, dmatrix *output);
//gsoap ns service method-documentation: RandomizeWeights sets the weights to random values in the minweight to maxweight interval
int ns__RandomizeWeights(int context, double minweight, double maxweight, ns__void_result *noresult);
//gsoap ns service method-documentation: InitWeights sets the weights to initial values based on the training data
int ns__InitWeights(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: SaveNet stores the neural network as floating point values in a file in the net subdirectory, if successful returns true
int ns__SaveNet(int context, std::string configurationfile, bool *success);
//gsoap ns service method-documentation: SaveFixed stores the neural network as fixed point values in a file in the net subdirectory, returns the fixpoint used for the values
int ns__SaveFixed(int context, std::string configurationfile, int *fixpoint);
//gsoap ns service method-documentation: Train 
int ns__Train(int context, dvector *input, dvector *desiredoutput, ns__void_result *noresult);
//gsoap ns service method-documentation: Test 
int ns__Test(int context, dvector *input, dvector *desiredoutput, dvector *output);
//gsoap ns service method-documentation: GetMSE 
int ns__GetMSE(int context, float *result);
//gsoap ns service method-documentation: ResetMSE 
int ns__ResetMSE(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: TrainEpoch 
int ns__TrainEpoch(int context, float *result);
//gsoap ns service method-documentation: TestData 
int ns__TestData(int context, float *result);

//gsoap ns service method-documentation: StopTraining 
int ns__StopTraining(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: TrainOnData 
int ns__TrainOnData(int context, unsigned int maxepochs,
    unsigned int epochsbetweenreports, float desirederror, dmatrix *result);
//gsoap ns service method-documentation: TrainOnFile 
int ns__TrainOnFile(int context, std::string filename, unsigned int maxepochs,
    unsigned int epochsbetweenreports, float desirederror, dmatrix *result);
//gsoap ns service method-documentation: PrintParameters 
int ns__PrintParameters(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: PrintConnections 
int ns__PrintConnections(int context, ns__void_result *noresult);

//gsoap ns service method-documentation: CascadeTrainOnData 
int ns__CascadeTrainOnData(int context, unsigned int maxneurons,
    unsigned int neuronsbetweenreports, float desirederror, dmatrix *result);
//gsoap ns service method-documentation: CascadeTrainOnFile 
int ns__CascadeTrainOnFile(int context, std::string filename, unsigned int maxneurons,
    unsigned int neuronsbetweenreports, float desirederror, dmatrix *result);
//gsoap ns service method-documentation: GetCascadeOutputChangeFraction 
int ns__GetCascadeOutputChangeFraction(int context, float *result);
//gsoap ns service method-documentation: SetCascadeOutputChangeFraction 
int ns__SetCascadeOutputChangeFraction(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeOutputStagnationEpochs 
int ns__GetCascadeOutputStagnationEpochs(int context, unsigned int *result);
//gsoap ns service method-documentation: SetCascadeOutputStagnationEpochs 
int ns__SetCascadeOutputStagnationEpochs(int context, unsigned int property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeCandidateChangeFraction 
int ns__GetCascadeCandidateChangeFraction(int context, float *result);
//gsoap ns service method-documentation: SetCascadeCandidateChangeFraction 
int ns__SetCascadeCandidateChangeFraction(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeCandidateStagnationEpochs 
int ns__GetCascadeCandidateStagnationEpochs(int context, unsigned int *result);
//gsoap ns service method-documentation: SetCascadeCandidateStagnationEpochs 
int ns__SetCascadeCandidateStagnationEpochs(int context, unsigned int property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeWeightMultiplier 
int ns__GetCascadeWeightMultiplier(int context, double *result);
//gsoap ns service method-documentation: SetCascadeWeightMultiplier 
int ns__SetCascadeWeightMultiplier(int context, double property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeCandidateLimit 
int ns__GetCascadeCandidateLimit(int context, double *result);
//gsoap ns service method-documentation: SetCascadeCandidateLimit 
int ns__SetCascadeCandidateLimit(int context, double property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeCandidateMaximumOutputEpochs 
int ns__GetCascadeCandidateMaximumOutputEpochs(int context, unsigned int *result);
//gsoap ns service method-documentation: SetCascadeCandidateMaximumOutputEpochs 
int ns__SetCascadeCandidateMaximumOutputEpochs(int context, unsigned int property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeCandidateMaximumCandidateEpochs 
int ns__GetCascadeCandidateMaximumCandidateEpochs(int context, unsigned int *result);
//gsoap ns service method-documentation: SetCascadeCandidateMaximumCandidateEpochs 
int ns__SetCascadeCandidateMaximumCandidateEpochs(int context, unsigned int property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeCandidateNumCandidates 
int ns__GetCascadeCandidateNumCandidates(int context, unsigned int *result);
//gsoap ns service method-documentation: GetCascadeCandidateNumCandidateGroups 
int ns__GetCascadeCandidateNumCandidateGroups(int context, unsigned int *result);
//gsoap ns service method-documentation: SetCascadeCandidateNumCandidateGroups 
int ns__SetCascadeCandidateNumCandidateGroups(int context, unsigned int property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeActivationFunctions 
int ns__GetCascadeActivationFunctions(int context, afvector *output);
//gsoap ns service method-documentation: SetCascadeActivationFunctions 
int ns__SetCascadeActivationFunctions(int context, afvector *input, ns__void_result *noresult);
//gsoap ns service method-documentation: GetCascadeActivationSteepnesses 
int ns__GetCascadeActivationSteepnesses(int context, dvector *output);
//gsoap ns service method-documentation: SetCascadeActivationSteepnesses 
int ns__SetCascadeActivationSteepnesses(int context, dvector *input, ns__void_result *noresult);

//gsoap ns service method-documentation: GetTrainingAlgorithm 
int ns__GetTrainingAlgorithm(int context, enum ns__TrainingAlgorithm *result);
//gsoap ns service method-documentation: SetTrainingAlgorithm 
int ns__SetTrainingAlgorithm(int context, enum ns__TrainingAlgorithm property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetLearningRate 
int ns__GetLearningRate(int context, float *result);
//gsoap ns service method-documentation: SetLearningRate 
int ns__SetLearningRate(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetActivationFunction 
int ns__GetActivationFunction(int context, int layer, int neuron, enum ns__ActivationFunction *result); 
//gsoap ns service method-documentation: SetActivationFunction 
int ns__SetActivationFunction(int context, enum ns__ActivationFunction property, int layer, int neuron, ns__void_result *noresult);
//gsoap ns service method-documentation: SetActivationFunctionLayer 
int ns__SetActivationFunctionLayer(int context, enum ns__ActivationFunction property, int layer, ns__void_result *noresult);
//gsoap ns service method-documentation: SetActivationFunctionHidden 
int ns__SetActivationFunctionHidden(int context, enum ns__ActivationFunction property, ns__void_result *noresult);
//gsoap ns service method-documentation: SetActivationFunctionOutput 
int ns__SetActivationFunctionOutput(int context, enum ns__ActivationFunction property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetActivationSteepness 
int ns__GetActivationSteepness(int context, int layer, int neuron, double *result);
//gsoap ns service method-documentation: SetActivationSteepness 
int ns__SetActivationSteepness(int context, double property, int layer, int neuron, ns__void_result *noresult);
//gsoap ns service method-documentation: SetActivationSteepnessLayer 
int ns__SetActivationSteepnessLayer(int context, double property, int layer, ns__void_result *noresult);
//gsoap ns service method-documentation: SetActivationSteepnessHidden 
int ns__SetActivationSteepnessHidden(int context, double property, ns__void_result *noresult);
//gsoap ns service method-documentation: SetActivationSteepnessOutput 
int ns__SetActivationSteepnessOutput(int context, double property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetErrorFunction 
int ns__GetErrorFunction(int context, enum ns__ErrorFunction *result);
//gsoap ns service method-documentation: SetErrorFunction 
int ns__SetErrorFunction(int context, enum ns__ErrorFunction property, ns__void_result *noresult);

//gsoap ns service method-documentation: GetQuickpropDecay 
int ns__GetQuickpropDecay(int context, float *result);
//gsoap ns service method-documentation: SetQuickpropDecay 
int ns__SetQuickpropDecay(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetQuickpropMu 
int ns__GetQuickpropMu(int context, float *result);
//gsoap ns service method-documentation: SetQuickpropMu 
int ns__SetQuickpropMu(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetRpropIncreaseFactor 
int ns__GetRpropIncreaseFactor(int context, float *result);
//gsoap ns service method-documentation: SetRpropIncreaseFactor 
int ns__SetRpropIncreaseFactor(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetRpropDecreaseFactor 
int ns__GetRpropDecreaseFactor(int context, float *result);
//gsoap ns service method-documentation: SetRpropDecreaseFactor 
int ns__SetRpropDecreaseFactor(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetRpropDeltaMin 
int ns__GetRpropDeltaMin(int context, float *result);
//gsoap ns service method-documentation: SetRpropDeltaMin 
int ns__SetRpropDeltaMin(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetRpropDeltaMax 
int ns__GetRpropDeltaMax(int context, float *result);
//gsoap ns service method-documentation: SetRpropDeltaMax 
int ns__SetRpropDeltaMax(int context, float property, ns__void_result *noresult);

//gsoap ns service method-documentation: GetNumInput 
int ns__GetNumInput(int context, unsigned int *result);
//gsoap ns service method-documentation: GetNumOutput 
int ns__GetNumOutput(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTotalNeurons 
int ns__GetTotalNeurons(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTotalConnections 
int ns__GetTotalConnections(int context, unsigned int *result);
//gsoap ns service method-documentation: GetNetworkType 
int ns__GetNetworkType(int context, enum ns__NetworkType *result);
//gsoap ns service method-documentation: GetConnectionRate 
int ns__GetConnectionRate(int context, float *result);
//gsoap ns service method-documentation: GetNumLayers 
int ns__GetNumLayers(int context, unsigned int *result);
//gsoap ns service method-documentation: GetLayers 
int ns__GetLayers(int context, ivector *result);
//gsoap ns service method-documentation: GetBias 
int ns__GetBias(int context, ivector *result);
//gsoap ns service method-documentation: GetConnections 
int ns__GetConnections(int context, dmatrix *result);
//gsoap ns service method-documentation: SetWeight 
int ns__SetWeight(int context, unsigned int fromneuron, unsigned int toneuron,
    double weight, ns__void_result *noresult);
//gsoap ns service method-documentation: SetWeights 
int ns__SetWeights(int context, dmatrix *connections, ns__void_result *noresult);

//gsoap ns service method-documentation: GetLearningMomentum 
int ns__GetLearningMomentum(int context, float *result);
//gsoap ns service method-documentation: SetLearningMomentum 
int ns__SetLearningMomentum(int context, float property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetStopFunction 
int ns__GetStopFunction(int context, enum ns__StopFunction *result);
//gsoap ns service method-documentation: SetStopFunction 
int ns__SetStopFunction(int context, enum ns__StopFunction property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetBitFailLimit 
int ns__GetBitFailLimit(int context, double *result);
//gsoap ns service method-documentation: SetBitFailLimit 
int ns__SetBitFailLimit(int context, double property, ns__void_result *noresult);
//gsoap ns service method-documentation: GetBitFail 
int ns__GetBitFail(int context, unsigned int *result);

//gsoap ns service method-documentation: ScaleTrain 
int ns__ScaleTrain(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: DescaleTrain 
int ns__DescaleTrain(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: ScaleTest 
int ns__ScaleTest(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: DescaleTest 
int ns__DescaleTest(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: SetInputScalingParams 
int ns__SetInputScalingParams(int context, float newinputmin, float newinputmax, bool *success);
//gsoap ns service method-documentation: SetOutputScalingParams 
int ns__SetOutputScalingParams(int context, float newoutputmin, float newoutputmax, bool *success);
//gsoap ns service method-documentation: SetScalingParams 
int ns__SetScalingParams(int context, float newinputmin, float newinputmax, float newoutputmin, float newoutputmax, bool *success);
//gsoap ns service method-documentation: ClearScalingParams 
int ns__ClearScalingParams(int context, bool *success);
//gsoap ns service method-documentation: ScaleInput 
int ns__ScaleInput(int context, dvector *inputvector, ns__void_result *noresult);
//gsoap ns service method-documentation: ScaleOutput 
int ns__ScaleOutput(int context, dvector *outputvector, ns__void_result *noresult);
//gsoap ns service method-documentation: DescaleInput 
int ns__DescaleInput(int context, dvector *inputvector, ns__void_result *noresult);
//gsoap ns service method-documentation: DescaleOutput 
int ns__DescaleOutput(int context, dvector *outputvector, ns__void_result *noresult);

//gsoap ns service method-documentation: ReadTrainFromFile 
int ns__ReadTrainFromFile(int context, std::string datafile, bool *success);
//gsoap ns service method-documentation: SaveTrain 
int ns__SaveTrain(int context, std::string datafile, bool *success);
//gsoap ns service method-documentation: SaveTrainToFixed 
int ns__SaveTrainToFixed(int context, std::string datafile, unsigned int decimalpoint, bool *success);
//gsoap ns service method-documentation: ShuffleTrainData 
int ns__ShuffleTrainData(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: MergeTestIntoTrainData 
int ns__MergeTestIntoTrainData(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: GetTrainNumData 
int ns__GetTrainNumData(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTrainNumInput 
int ns__GetTrainNumInput(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTrainNumOutput 
int ns__GetTrainNumOutput(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTrainInput 
int ns__GetTrainInput(int context, dmatrix *result);
//gsoap ns service method-documentation: GetTrainOutput 
int ns__GetTrainOutput(int context, dmatrix *result);
//gsoap ns service method-documentation: SetTrainData 
int ns__SetTrainData(int context, dmatrix *input, dmatrix *output, ns__void_result *noresult);

//gsoap ns service method-documentation: ScaleTrainData 
int ns__ScaleTrainData(int context, double minimum, double maximum, ns__void_result *noresult);
//gsoap ns service method-documentation: ScaleTrainInput 
int ns__ScaleTrainInput(int context, double minimum, double maximum, ns__void_result *noresult);
//gsoap ns service method-documentation: ScaleTrainOutput 
int ns__ScaleTrainOutput(int context, double minimum, double maximum, ns__void_result *noresult);
//gsoap ns service method-documentation: SubsetTrainData 
int ns__SubsetTrainData(int context, unsigned int position, unsigned int length, ns__void_result *noresult);

//gsoap ns service method-documentation: ReadTestFromFile 
int ns__ReadTestFromFile(int context, std::string datafile, bool *success);
//gsoap ns service method-documentation: SaveTest 
int ns__SaveTest(int context, std::string datafile, bool *success);
//gsoap ns service method-documentation: SaveTestToFixed 
int ns__SaveTestToFixed(int context, std::string datafile, unsigned int decimalpoint, bool *success);
//gsoap ns service method-documentation: ShuffleTestData 
int ns__ShuffleTestData(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: MergeTrainIntoTestData 
int ns__MergeTrainIntoTestData(int context, ns__void_result *noresult);
//gsoap ns service method-documentation: GetTestNumData 
int ns__GetTestNumData(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTestNumInput 
int ns__GetTestNumInput(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTestNumOutput 
int ns__GetTestNumOutput(int context, unsigned int *result);
//gsoap ns service method-documentation: GetTestInput 
int ns__GetTestInput(int context, dmatrix *result);
//gsoap ns service method-documentation: GetTestOutput 
int ns__GetTestOutput(int context, dmatrix *result);
//gsoap ns service method-documentation: SetTestData 
int ns__SetTestData(int context, dmatrix *input, dmatrix *output, ns__void_result *noresult);

//gsoap ns service method-documentation: ScaleTestData 
int ns__ScaleTestData(int context, double minimum, double maximum, ns__void_result *noresult);
//gsoap ns service method-documentation: ScaleTestInput 
int ns__ScaleTestInput(int context, double minimum, double maximum, ns__void_result *noresult);
//gsoap ns service method-documentation: ScaleTestOutput 
int ns__ScaleTestOutput(int context, double minimum, double maximum, ns__void_result *noresult);
//gsoap ns service method-documentation: SubsetTestData 
int ns__SubsetTestData(int context, unsigned int position, unsigned int length, ns__void_result *noresult);
