// Copyright 2005/2548 written by freegoldbar at yahoo dot com.
// All rights reserved. For private and educational use.
// Not for sale, commercial or military use.
// No warranties given. No suitability for any purpose.

#include "soapH.h"

////////////////////////////////////////////////////////////////////////////////
//
//  dvector
//
////////////////////////////////////////////////////////////////////////////////

dvector::dvector()
{
    dvector(NULL);
}

dvector::dvector(struct soap *env)
{
    soap = env;
    __ptr = 0;
    __size = 0;
}

dvector::dvector(struct soap *env, int size)
{
    soap = env;
    __size = size;
    __ptr = (double*)soap_malloc(soap, size*sizeof(double));
    for (int i = 0; i < size; i++)
        __ptr[i] = 0.0;
}

dvector::~dvector()
{
    // no deallocation: let gSOAP handle dynamic allocation and deallocation
}

int dvector::size()
{
    return __size;
}

void dvector::set_size(int size)
{
//    if (__size == size)
//        return; // nothing to do
    double *p = (double*)soap_malloc(soap, size*sizeof(double));
    for (int i = 0; i < size; i++)
        p[i] = 0.0;
    __ptr = p;
    __size = size;
}

double& dvector::operator[](int i)
{
    return __ptr[i];
}

////////////////////////////////////////////////////////////////////////////////
//
//  ivector
//
////////////////////////////////////////////////////////////////////////////////

ivector::ivector()
{
    ivector(NULL);
}

ivector::ivector(struct soap *env)
{
    soap = env;
    __ptr = 0;
    __size = 0;
}

ivector::ivector(struct soap *env, int size)
{
    soap = env;
    __size = size;
    __ptr = (int*)soap_malloc(soap, size*sizeof(int));
    for (int i = 0; i < size; i++)
        __ptr[i] = 0;
}

ivector::~ivector()
{
    // no deallocation: let gSOAP handle all dynamic allocation and deallocation
}

int ivector::size()
{
    return __size;
}

void ivector::set_size(int size)
{
//    if (__size == size)
//        return; // nothing to do
    int *p = (int*)soap_malloc(soap, size*sizeof(int));
    for (int i = 0; i < size; i++)
        p[i] = 0;
    __ptr = p;
    __size = size;
}

int& ivector::operator[](int i)
{
    return __ptr[i];
}

////////////////////////////////////////////////////////////////////////////////
//
//  afvector
//
////////////////////////////////////////////////////////////////////////////////

afvector::afvector()
{
    afvector(NULL);
}

afvector::afvector(struct soap *env)
{
    soap = env;
    __ptr = 0;
    __size = 0;
}

afvector::afvector(struct soap *env, int size)
{
    soap = env;
    __size = size;
    __ptr = (enum ns__ActivationFunction*)soap_malloc(soap, size*sizeof(enum ns__ActivationFunction));
    for (int i = 0; i < size; i++)
        __ptr[i] = static_cast<enum ns__ActivationFunction>(0);
}

afvector::~afvector()
{
    // no deallocation: let gSOAP handle all dynamic allocation and deallocation
}

int afvector::size()
{
    return __size;
}

void afvector::set_size(int size)
{
//    if (__size == size)
//        return; // nothing to do
    enum ns__ActivationFunction *p = (enum ns__ActivationFunction*)soap_malloc(soap, size*sizeof(int));
    for (int i = 0; i < size; i++)
        p[i] = static_cast<enum ns__ActivationFunction>(0);
    __ptr = p;
    __size = size;
}

enum ns__ActivationFunction& afvector::operator[](int i)
{
    return __ptr[i];
}

////////////////////////////////////////////////////////////////////////////////
//
//  dmatrix
//
////////////////////////////////////////////////////////////////////////////////

dmatrix::dmatrix()
{
    dmatrix(NULL);
}

dmatrix::dmatrix(struct soap *env)
{
    soap = env;
    __ptr = 0;
    __size = 0;
}

dmatrix::dmatrix(struct soap *env, int rows, int cols)
{
    soap = env;
    __size = rows;
    __ptr = soap_new_dvector(soap, __size);
    for (int i = 0; i < __size; i++)
        __ptr[i].set_size(cols);
}

dmatrix::~dmatrix()
{
    // no deallocation: let gSOAP handle all dynamic allocation and deallocation
}

int dmatrix::size()
{
    return __size;
}

void dmatrix::set_size(int rows, int cols)
{
    __size = rows;
    __ptr = soap_new_dvector(soap, rows);
    for (int i = 0; i < rows; i++)
        __ptr[i].set_size(cols);
}

dvector& dmatrix::operator[](int i)
{
    return __ptr[i];
}

////////////////////////////////////////////////////////////////////////////////
//
//  stringvector
//
////////////////////////////////////////////////////////////////////////////////

stringvector::stringvector()
{
    stringvector(NULL);
}

stringvector::stringvector(struct soap *env)
{
    soap = env;
    __ptr = 0;
    __size = 0;
}

stringvector::stringvector(struct soap *env, int size)
{
    soap = env;
    __size = size;
    __ptr = (std::string **)soap_malloc(soap, size*sizeof(std::string *));
    for (int i = 0; i < size; i++)
        __ptr[i] = new std::string;
}

stringvector::~stringvector()
{
    for (int i = 0; i < __size; i++)
        delete(__ptr[i]);
    // no further deallocation
}

int stringvector::size()
{
    return __size;
}

void stringvector::resize(int size)
{
    std::string **p;

    if (size == __size)
        return; // nothing to do
    p = (std::string **)soap_malloc(soap, size*sizeof(std::string *));
    if (__ptr)
    {
        if (size < __size) // shrinking
        {
            for (int i = 0; i < size; i++)
                p[i] = __ptr[i];
            for (int i = size; i < __size; i++)
                delete(__ptr[i]);
        }
        else // expanding
        {
            for (int i = 0; i < __size; i++)
                p[i] = __ptr[i];
            for (int i = __size; i < size; i++)
                p[i] = new std::string;
        }
    }
    else
    {
        for (int i = 0; i < size; i++)
            p[i] = new std::string;
    }
    __ptr = p;
    __size = size;
}

std::string& stringvector::operator[](int i)
{
    return *__ptr[i];
}
