(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5218,        158]*)
(*NotebookOutlinePosition[      5882,        181]*)
(*  CellTagsIndexPosition[      5838,        177]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Sample using fannKernel via fannDotNet"
}], "Section"],

Cell["First start fannKernel on the local machine.", "Text"],

Cell["\<\
Set up the path to the fannDotNet proxy dll. Edit this according to your \
installation.\
\>", "Text"],

Cell[BoxData[
    \(\(fannDotNetDirectory = "\<C:/Documents and Settings/sony user/My \
Documents/Visual Studio Projects/\>" <> \
"\<fann/fannSoap/fannDotNet/\>";\)\)], "Input"],

Cell["Load NETLink and the fannKernel functions and types.", "Text"],

Cell[BoxData[{
    \(Needs["\<NETLink`\>"]\), "\n", 
    \(\(InstallNET[];\)\), "\n", 
    \(\(fannAssembly = 
        LoadNETAssembly[
          fannDotNetDirectory <> "\<fannDotNet.dll\>"];\)\), "\n", 
    \(\(fannType = 
        LoadNETType["\<fannDotNet.fannProxy.fannKernel\>"];\)\), "\n", 
    \(\(activationFunction = 
        LoadNETType["\<fannDotNet.fannProxy.ActivationFunction\>"];\)\), "\n\
", 
    \(\(errorFunction = 
        LoadNETType["\<fannDotNet.fannProxy.ErrorFunction\>"];\)\), "\n", 
    \(\(networkType = 
        LoadNETType["\<fannDotNet.fannProxy.NetworkType\>"];\)\), "\n", 
    \(\(trainingAlgorithm = 
        LoadNETType["\<fannDotNet.fannProxy.TrainingAlgorithm\>"];\)\), "\n", \

    \(\(fann = NETNew[fannType];\)\)}], "Input"],

Cell["This will list the fannKernel API", "Text"],

Cell[BoxData[
    \(NETTypeInfo[fannType]\)], "Input"],

Cell["\<\
Create a context in fannKernel to uniquely identify a neural network and its \
data\
\>", "Text"],

Cell[BoxData[
    \(\(net = fann@CreateContext[];\)\)], "Input"],

Cell["\<\
Create a simple neural network for the xor problem and read the training data \
from the xor.train sample file.\
\>", "Text"],

Cell[BoxData[{
    \(\(fann@Create[net, NetworkType`Layer, {2, 3, 1}, 1.0];\)\), "\n", 
    \(\(fann@SetLearningRate[net, 0.7];\)\), "\n", 
    \(\(fann@SetActivationSteepnessHidden[net, 1.0];\)\), "\n", 
    \(\(fann@SetActivationSteepnessOutput[net, 1.0];\)\), "\n", 
    \(\(fann@
        SetActivationFunctionHidden[net, 
          ActivationFunction`SigmoidSymmetricStepwise];\)\), "\n", 
    \(\(fann@
        SetActivationFunctionOutput[net, 
          ActivationFunction`SigmoidSymmetricStepwise];\)\), "\n", 
    \(\(fann@ReadTrainFromFile[net, "\<xor.train\>"];\)\)}], "Input"],

Cell["\<\
Initialize the neural network, train it, plot the mean square error and view \
its output. Try it a couple of times if it does not converge.\
\>", "Text"],

Cell[BoxData[{
    \(\(fann@InitWeights[net];\)\), "\n", 
    \(\(mse = fann@TrainOnData[net, 300, 3, 0.001];\)\), "\n", 
    \(\(ListPlot[mse, \ PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {Hue[1.0]}];\)\), "\n", 
    \(fann@
      RunData[net, {{\(-1\), \(-1\)}, {\(-1\), 1}, {1, \(-1\)}, {1, 
            1}}]\)}], "Input"],

Cell["Get the connections and weights in the neural network.", "Text"],

Cell[BoxData[
    \(cn = fann@GetConnections[net]\)], "Input"],

Cell["Half all the weights and view the output.", "Text"],

Cell[BoxData[{
    \(\(cn\[LeftDoubleBracket]All, 3\[RightDoubleBracket] /= 2;\)\), "\n", 
    \(\(fann@SetWeights[net, cn];\)\), "\n", 
    \(fann@
      RunData[net, {{\(-1\), \(-1\)}, {\(-1\), 1}, {1, \(-1\)}, {1, 
            1}}]\)}], "Input"],

Cell["Done with this sample so remove the context from fannKernel.", "Text"],

Cell[BoxData[
    \(fann@DestroyContext[net]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 691}},
WindowSize->{790, 662},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 126, 4, 73, "Section"],
Cell[1905, 59, 60, 0, 33, "Text"],
Cell[1968, 61, 112, 3, 33, "Text"],
Cell[2083, 66, 177, 3, 70, "Input"],
Cell[2263, 71, 68, 0, 33, "Text"],
Cell[2334, 73, 762, 18, 190, "Input"],
Cell[3099, 93, 49, 0, 33, "Text"],
Cell[3151, 95, 54, 1, 30, "Input"],
Cell[3208, 98, 107, 3, 33, "Text"],
Cell[3318, 103, 64, 1, 30, "Input"],
Cell[3385, 106, 135, 3, 33, "Text"],
Cell[3523, 111, 587, 11, 150, "Input"],
Cell[4113, 124, 164, 3, 33, "Text"],
Cell[4280, 129, 334, 7, 90, "Input"],
Cell[4617, 138, 70, 0, 33, "Text"],
Cell[4690, 140, 62, 1, 30, "Input"],
Cell[4755, 143, 57, 0, 33, "Text"],
Cell[4815, 145, 248, 5, 70, "Input"],
Cell[5066, 152, 76, 0, 33, "Text"],
Cell[5145, 154, 57, 1, 30, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

